@@ -15,5 +15,6 @@ plogseries <- function(q, alpha, lower.tail = TRUE, log.p = FALSE) {
 rlogseries <- function(n, alpha) {
   val <- integer(n)
   alpha <- rep(alpha, len = n)
-  .C("rlogseries_R", as.integer(n), as.double(alpha), val = as.integer(val))$val
+  .C("rlogseries_R", as.integer(n), as.double(alpha), val = as.integer(val),
+     PACKAGE = "copula")$val
 }
